@@ -449,9 +449,14 @@ def template_sync(request):
     if not has_perm(request.user,'campaign_monitor.add_template'):
         raise Http403
     
-    sync_templates(request)
+    success = sync_templates(request)
     
-    messages.add_message(request, messages.SUCCESS, 'Successfully synced with Campaign Monitor')
+    if success:
+        messages.add_message(
+            request,
+            messages.SUCCESS,
+            'Successfully synced with Campaign Monitor')
+
     return redirect("campaign_monitor.template_index")
 
 @login_required
