@@ -50,8 +50,8 @@ class MemberAppEntryIndex(TendenciBaseSearchIndex):
 
 
 site.register(App, MemberAppIndex)
-site.register(AppEntry, MemberAppEntryIndex)
 
 # Removed from index after search view was updated to perform
 # all searches on the database.
+# site.register(AppEntry, MemberAppEntryIndex)
 # site.register(MembershipDefault, MembershipDefaultIndex)
