@@ -10,13 +10,13 @@ jQuery(function($) {
 });
 function update() {
     $('.row1, .row2').each(function(i) {
-        $(this).find('input[id$=order]').val(i+1);
+        $(this).find('input[id$=position]').val(i+1);
     });
 }
 jQuery(document).ready(function($){
     // hide order
-    var order_index = $('div.inline-related').find('td.field-order').index();
-    $('div.inline-related').find('td.field-order').hide();
+    var order_index = $('div.inline-related').find('td.field-position').index();
+    $('div.inline-related').find('td.field-position').hide();
     $('div.inline-related').find('th:nth-child(' + order_index +')').hide();
     
     //$('div.inline-related tr').css('cursor','move');
