@@ -15,20 +15,28 @@ class InvoiceManager(Manager):
                            balance=kwargs.get('balance', 0),
                            creator=user, 
                            creator_username=user.username,
-                           owner=user, 
+                           owner=user,
                            owner_username=user.username)
-        
+
     def search(self, query=None, *args, **kwargs):
         """
-            invoice haystack to query invoices. 
+            invoice haystack to query invoices.
             Returns a SearchQuerySet
         """
         from tendenci.apps.invoices.models import Invoice
         sqs = SearchQuerySet()
-       
+
         if query: 
             sqs = sqs.filter(content=sqs.query.clean(query))
         else:
             sqs = sqs.all()
-        
-        return sqs.models(Invoice)
\ No newline at end of file
+
+        return sqs.models(Invoice)
+
+    def first(self, **kwargs):
+        """
+        Returns first instance that matches filters.
+        If no instance is found then a none type object is returned.
+        """
+        [instance] = self.filter(**kwargs).order_by('pk')[:1] or [None]
+        return instance
