@@ -8,14 +8,14 @@ from tendenci.core.perms.admin import TendenciBaseModelAdmin
 class GroupAdmin(TendenciBaseModelAdmin):
     list_display = ['id', 'name', 'label', 'entity', 'show_as_option', 'allow_self_add', 'allow_self_remove', 'admin_status']
     search_fields = ['name', 'label', 'entity__entity_name']
-    list_filter = ['status', 'entity', 'show_as_option', 'allow_self_add']
+    list_filter = ['entity', 'show_as_option', 'allow_self_add']
     list_editable = ['name', 'label', 'entity']
     fieldsets = (
         (None, {'fields': ('name', 'label', 'entity', 'email_recipient', 'permissions')}),
         ('Flags', {'fields': (
             'show_as_option', 'allow_self_add', 'allow_self_remove', 'sync_newsletters')}),
         ('Administrative', {'fields': (
-            'allow_anonymous_view', 'user_perms', 'member_perms', 'group_perms', 'status', 'status_detail')}),
+            'allow_anonymous_view', 'user_perms', 'member_perms', 'group_perms', 'status_detail')}),
     )
     form = GroupAdminForm
 
@@ -32,4 +32,4 @@ admin.site.register(Group, GroupAdmin)
 
 from django.contrib.auth.models import Group as AuthGroup
 # unregister AuthGroup
-admin.site.unregister(AuthGroup)
\ No newline at end of file
+admin.site.unregister(AuthGroup)
